@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 # Author: Labstep <dev@labstep.com>
 
+import json
 import labstep.entities.file.repository as fileRepository
 import labstep.generic.entity.repository as entityRepository
 from labstep.generic.entityList.model import EntityList
@@ -11,6 +12,7 @@ from labstep.entities.experimentProtocol.model import ExperimentProtocol
 from labstep.entities.resource.model import Resource
 from labstep.entities.resourceItem.model import ResourceItem
 from labstep.entities.file.model import File
+from labstep.entities.deviceData.model import DeviceData
 from labstep.constants import UNSPECIFIED
 
 
@@ -82,6 +84,10 @@ def editDataField(dataField, fieldName=UNSPECIFIED, value=UNSPECIFIED, extraPara
 
 def getDataFieldValue(dataField):
 
+
+    if dataField.device_data is not None:
+        dataField = DeviceData(dataField.device_data,dataField.__user__)
+
     if dataField.type == 'default':
         return dataField.value
 
@@ -114,6 +120,9 @@ def getDataFieldValue(dataField):
         else:
             return EntityList(dataField.files, File, dataField.__user__)
 
+    if dataField.type == 'sequence':
+        return json.loads(dataField.sequence['data'])
+
     return None
 
 
