@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # Author: Labstep <dev@labstep.com>
 
-from labstep.generic.entity.model import Entity
+from labstep.generic.entityWithComments.model import EntityWithComments
 from labstep.entities.jupyterNotebook.model import JupyterNotebook
 from labstep.entities.protocolDataField.model import ProtocolDataField
 from labstep.entities.protocolStep.model import ProtocolStep
@@ -16,13 +16,14 @@ import labstep.entities.file.repository as fileRepository
 from labstep.constants import UNSPECIFIED
 
 
-class ProtocolVersion(Entity):
+class ProtocolVersion(EntityWithComments):
     __entityName__ = "protocol"
     __isLegacy__ = True
 
     def __init__(self, data, user):
         self.state = None
         super().__init__(data, user)
+        self.name = f'{self.name} v{self.version + 1}'
 
     def edit(self, body=UNSPECIFIED, extraParams={}):
         """
@@ -514,3 +515,23 @@ class ProtocolVersion(Entity):
         import labstep.entities.jupyterNotebook.repository as jupyterNotebookRepository
 
         return jupyterNotebookRepository.newJupyterNotebook(self.__user__, name, data, extraParams={'protocol_id': self.id})
+
+    def export(self, path):
+        """
+        Export the protocol version to the directory specified.
+
+        Parameters
+        -------
+        path (str)
+            The path to the directory to save the protocol version.
+
+        Example
+        -------
+        ::
+
+            experiment = user.getProtocol(17000)
+            experiment.export('/my_folder')
+        """
+        import labstep.entities.protocolVersion.repository as protocolVersionRepository
+
+        return protocolVersionRepository.exportProtocolVersion(self, path)
